﻿using Com.Bocom.OpenApi.Utils;
using Kivii;
using Kivii.Finances.Entities;
using Kivii.Text;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using static Com.Bocom.OpenApi.AddContractOrderRequestV2.AddContractOrderRequestV2Biz;

namespace Com.Bocom.OpenApi
{
    public static class Extension
    {
        public static AddContractOrderResponseV2 RequestAddContractOrderV2(Settlement settlement, out string err)
        {
            if (settlement == null)
            {
                err = string.Empty;
                return null;
            }
            DefaultBocomClient client = new DefaultBocomClient(Configs.APP_ID, Configs.MY_PRIVATE_KEY, Configs.APIGW_PUBLIC_KEY, BocomConstants.ENCRYPT_TYPE_RSA_AND_AES);
            /**
			* 测试环境可以忽略SSL证书告警，生产环境不可忽略
			*/
            client.IgnoreSslHostnameVerifier();

            var bizKvid = settlement.Kvid.ToString();

            var request = new AddContractOrderRequestV2();
            request.SetServiceUrl(Configs.APIGW_URL_ADDRESS + Configs.AddContractOrderRequestV2);

            var bizContent = new AddContractOrderRequestV2.AddContractOrderRequestV2Biz();
            bizContent.org_id = Configs.ORG_ID;
            bizContent.bat_id = bizKvid;
            bizContent.cont_order_list = new List<ContOrder>();
            var contorder = new ContOrder();
            contorder.cont_id = bizKvid;
            contorder.org_id = bizContent.org_id;
            contorder.ori_payer = settlement.PayerName;
            //contorder.ori_ac = "";
            //contorder.ori_addr = "仅记录";
            //contorder.ori_tel_no = "仅记录";
            //contorder.ori_other_info1 = "仅记录";
            //contorder.ori_other_info2 = "仅记录";
            //contorder.ori_other_info3 = "仅记录";
            contorder.ori_itm_nme = settlement.BizId;
            contorder.ori_amt = settlement.AmountPlan.ToString();
            contorder.ori_offset_amt = (settlement.AmountPlan - settlement.Amount).ToString();
            contorder.ori_act_amt = settlement.Amount.ToString();
            //contorder.attach_code = "";
            contorder.remark = settlement.Remark;
            //contorder.offset_remark = "测试2";
            contorder.payment_period = $"{DateTime.Now.AddMonths(-2).ToString("yyyy-MM-dd")}~{DateTime.Now.AddMonths(7).ToString("yyyy-MM-dd")}";
            contorder.agreement_type = "-1";
            bizContent.cont_order_list.Add(contorder);

            request.SetBizContent(bizContent);
            var response = client.Execute(request, Guid.NewGuid().ToString().Replace("-", ""));
            var rtns = new AddContractOrderResponseV2();
            if (response.IsSuccess())
            {
                rtns = response as AddContractOrderResponseV2;
                err = string.Empty;
                return rtns;
            }
            else
            {
                err = response.GetRspMsg();
                return null;
            }

        }

        public static DelContractOrderResponseV1 RequestDelContractOrderResponseV1(Settlement settlement, out string err)
        {
            if (settlement == null || settlement.Metadata.IsNullOrEmpty() || settlement.Metadata["BocomBillId"].IsNullOrEmpty())
            {
                err = string.Empty;
                return null;
            }
            var billId = settlement.Metadata["BocomBillId"];
            //Console.WriteLine($"---------------BocomBillId:{billId}-------------------");
            DefaultBocomClient client = new DefaultBocomClient(Configs.APP_ID, Configs.MY_PRIVATE_KEY, Configs.APIGW_PUBLIC_KEY, BocomConstants.ENCRYPT_TYPE_RSA_AND_AES);
            /**
			* 测试环境可以忽略SSL证书告警，生产环境不可忽略
			*/
            client.IgnoreSslHostnameVerifier();
            var request = new DelContractOrderRequestV1();
            request.SetServiceUrl(Configs.APIGW_URL_ADDRESS + Configs.DelContractOrderRequestV1);

            var bizContent = new DelContractOrderRequestV1.DelContractOrderRequestV1Biz();
            bizContent.org_id = Configs.ORG_ID;
            bizContent.bill_id = billId;
            request.SetBizContent(bizContent);
            var response = client.Execute(request, Guid.NewGuid().ToString().Replace("-", ""));
            var rtns = new DelContractOrderResponseV1();
            if (response.IsSuccess())
            {
                rtns = response as DelContractOrderResponseV1;
                err = string.Empty;
                //Console.WriteLine($"---------------DelContractOrder:Success-------------------");
                return rtns;
            }
            else
            {
                err = response.GetRspMsg();
                //Console.WriteLine($"---------------err:{err}-------------------");
                return null;
            }
        }
    }
}
